You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@commons.apache.org by gg...@apache.org on 2012/03/28 18:03:50 UTC

svn commit: r1306445 - /commons/proper/codec/trunk/src/main/java/org/apache/commons/codec/net/URLCodec.java

Author: ggregory
Date: Wed Mar 28 16:03:50 2012
New Revision: 1306445

URL: http://svn.apache.org/viewvc?rev=1306445&view=rev
Log:
Add deprecation.

Modified:
    commons/proper/codec/trunk/src/main/java/org/apache/commons/codec/net/URLCodec.java

Modified: commons/proper/codec/trunk/src/main/java/org/apache/commons/codec/net/URLCodec.java
URL: http://svn.apache.org/viewvc/commons/proper/codec/trunk/src/main/java/org/apache/commons/codec/net/URLCodec.java?rev=1306445&r1=1306444&r2=1306445&view=diff
==============================================================================
--- commons/proper/codec/trunk/src/main/java/org/apache/commons/codec/net/URLCodec.java (original)
+++ commons/proper/codec/trunk/src/main/java/org/apache/commons/codec/net/URLCodec.java Wed Mar 28 16:03:50 2012
@@ -60,10 +60,11 @@ public class URLCodec implements BinaryE
     /**
      * The default charset used for string decoding and encoding.
      * 
      * TODO: This field will be final in 2.0.
      */
+    @Deprecated
     protected String charset;
-    
+
     /**
      * Release 1.5 made this field final.
      */
@@ -60,10 +60,11 @@ public class URLCodec implements BinaryE
      * The default charset used for string decoding and encoding.
      * 
-     * TODO: This field will be final in 2.0.
+     * @deprecated TODO: This field will be changed to a private final Charset in 2.0.
      */